@@ -1,7 +1,7 @@
 use std::error::Error;
 use std::fmt;
 
-/// Type which returns a Result with a type of T and Error an type of EmptyVecErr
+/// Type which returns a Result with a type of T and an Error type of EmptyVecErr
 pub type ErrResult<T> = std::result::Result<T, Box<dyn Error>>;
 
 /// Error which shows up when no transactions have happened in a Blockchain
@@ -12,9 +12,6 @@ impl Error for EmptyVecErr {}
 
 impl fmt::Display for EmptyVecErr {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(
-            f,
-            "\x1b[31m\x1b[1mError: No transactions have happened!\x1b[0m"
-        )
+        write!(f, "Error: No transactions have happened!")
     }
 }
